==> haskell-hspec-wai-json-0.11.0-667-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-JvsFBwVT1ZuH4Y9RaTS7XR
key:                  hspec-wai-json-0.11.0-JvsFBwVT1ZuH4Y9RaTS7XR
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  1007b3f8508335680f04f529d7282865
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.11.0-JvsFBwVT1ZuH4Y9RaTS7XR
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    aeson-qq-0.8.4-6ZpV8cLkcm5HJDnyjdQ0cg base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7
    hspec-wai-0.11.1-6xyAx7ZwUWCDF4KgPxiH8g template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.11.0-694-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-2g847l2kT5lHvdvdftYx28
key:                  hspec-wai-json-0.11.0-2g847l2kT5lHvdvdftYx28
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  9eac063fb92bda65c0a7dd94b854076e
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.11.0-2g847l2kT5lHvdvdftYx28
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    aeson-qq-0.8.4-8BRi8qcqtJm4r2Wm0mWdHN base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY
    hspec-wai-0.11.1-3JBD90yGVHhHBjBNBEVvOx template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
